@@ -252,6 +252,26 @@ extern "C"
 {
 #endif
 
+#if !defined(MZ_NORETURN)
+# if defined(__GNUC__) || defined(__clang__)
+#  define MZ_NORETURN __attribute__((noreturn))
+# elif defined(_MSC_VER)
+#  define MZ_NORETURN __declspec(noreturn)
+# else
+#  define MZ_NORETURN
+# endif /* defined(__GNUC__) || defined(__clang__) */
+#endif /* !defined(MZ_NORETURN) */
+
+#if !defined(MZ_UNREACHABLE)
+# if (defined(__GNUC__) && (__GNUC__ > 4)) || defined(__clang__)
+#  define MZ_UNREACHABLE __builtin_unreachable()
+# elif defined(_MSC_VER)
+#  define MZ_UNREACHABLE __assume(0)
+# else
+#  define MZ_UNREACHABLE
+# endif /* defined(__GNUC__) || defined(__clang__) */
+#endif /* !defined(MZ_UNREACHABLE) */
+
 /* Allowed by all configurations, currently: */
 #define MZ_CAN_ACCESS_THREAD_LOCAL_DIRECTLY
 
@@ -1664,7 +1684,7 @@ MZ_EXTERN Scheme_Object *scheme_eval_waiting;
 #endif
 
 #ifdef MZ_USE_JIT
-MZ_EXTERN void scheme_jit_longjmp(mz_jit_jmp_buf b, int v);
+MZ_EXTERN MZ_NORETURN void scheme_jit_longjmp(mz_jit_jmp_buf b, int v);
 MZ_EXTERN void scheme_jit_setjmp_prepare(mz_jit_jmp_buf b);
 # define scheme_jit_setjmp(b) (scheme_jit_setjmp_prepare(b), scheme_call_mz_setjmp((b)->jb))
 #else
